==> zent-9.12.16.tgz: package/es/i18n/ja-JP.js <==
import { __assign } from "tslib";
import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { jaJP, setLocale } from './time-locale';
var common = {
    confirm: '確認',
    cancel: 'キャンセル',
    comma: ', ',
    ok: '了解',
    reset: 'リセット',
};
export var mark = 'ja-JP';
export var CopyButton = {
    copy: 'コピー',
    success: 'コピーしました',
    error: 'コピーに失敗しました',
};
export var Pagination = {
    jumpTo: function (_a) {
        var input = _a.input;
        return _jsxs(_Fragment, { children: ["\u30DA\u30FC\u30B8\u6307\u5B9A ", input] }, void 0);
    },
    pageStats: function (_a) {
        var total = _a.total, Text = _a.Text, select = _a.select;
        return (_jsxs(_Fragment, { children: ["\u5408\u8A08 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u9805\u76EE, ", select, _jsx(Text, __assign({ type: "right" }, { children: "/\u30DA\u30FC\u30B8" }), void 0)] }, void 0));
    },
    pageStatsStatic: function (_a) {
        var total = _a.total, pageSize = _a.pageSize, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["\u5408\u8A08 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u9805\u76EE,", _jsx(Text, __assign({ type: "middle" }, { children: pageSize }), void 0), " /\u30DA\u30FC\u30B8"] }, void 0));
    },
    selectWidth: 100,
    items: '',
};
export var Pop = __assign({}, common);
export var PreviewImage = {
    alt: '画像のダウンロードに失敗しました',
    prev: '前',
    next: '次',
    rotate: '回転',
};
export var RangePicker = {
    7: '7日間',
    30: '30日間',
};
export var Select = {
    input: '選択',
    empty: '見つかりません',
    tagSeparator: ', ',
    create: '+作成: ',
};
export var Sweetalert = __assign(__assign({}, common), { title: 'アラート' });
export var Switch = {
    checked: 'オン',
    unchecked: 'オフ',
};
export var Grid = __assign(__assign({}, common), { emptyLabel: 'データがありません' });
export var Cascader = __assign(__assign({}, common), { title: 'タイトル', placeholder: '選択', searchPlaceholder: '選択/検索', searchEmpty: '見つかりません', empty: '見つかりません' });
var QUARTER_NAMES = ['1期', '2期', '3期', '4期'];
export var TimePicker = function () {
    setLocale(jaJP);
    return __assign(__assign({}, common), { time: '時間を選択', date: '日付を選択', week: '週を選択', month: '月を選択', quarter: '期を選択', year: '年を選択', range: '範囲を選択', timeErrorPop: '選択された時間が無効です', dateErrorPop: '選択された日付が無効です', start: '開始日', end: '終了日', startTime: '開始時間', endTime: '終了時間', to: '〜', current: {
            time: '現在',
            date: '今日',
            week: '今週',
            month: '今月',
            year: '今年',
        }, panel: {
            hour: '',
            minute: '',
            second: '',
            year: '',
            hourSelect: '時間を選択',
            minuteSelect: '分を選択',
            secondSelect: '秒を選択',
            titleFormat: 'MMMM YYYY',
            quarterNames: QUARTER_NAMES,
            yearQuarterName: function (_a) {
                var year = _a.year, quarter = _a.quarter;
                var val = QUARTER_NAMES[quarter];
                return year + "/" + val;
            },
            dayNames: ['日', '月', '火', '水', '木', '金', '土'],
            monthNames: [
                '1月',
                '2月',
                '3月',
                '4月',
                '5月',
                '6月',
                '7月',
                '8月',
                '9月',
                '10月',
                '11月',
                '12月',
            ],
        } });
};
export var Upload = __assign(__assign({}, common), { delete: '削除', retry: '再度試す', failed: '失敗', limit: 'ファイル数の上限に達しました', add: 'ファイル追加', uploading: 'アップロード中' });
export var Mention = {
    noContent: '該当ありません。SPACEキーで終了',
};
export var Transfer = {
    placeholder: '',
    item: '項目',
    items: '項目',
    emptyLabel: '',
};
export var Form = {
    required: '必須',
};

==> zent-10.0.15.tgz: package/es/i18n/ja-JP.js <==
import { __assign } from "tslib";
import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { jaJP, setLocale } from './time-locale';
var common = {
    confirm: '確認',
    cancel: 'キャンセル',
    comma: ', ',
    ok: '了解',
    reset: 'リセット',
};
export var mark = 'ja-JP';
export var CopyButton = {
    copy: 'コピー',
    success: 'コピーしました',
    error: 'コピーに失敗しました',
};
export var Pagination = {
    jumpTo: function (_a) {
        var input = _a.input;
        return _jsxs(_Fragment, { children: ["\u30DA\u30FC\u30B8\u6307\u5B9A ", input] }, void 0);
    },
    pageStats: function (_a) {
        var total = _a.total, Text = _a.Text, select = _a.select;
        return (_jsxs(_Fragment, { children: ["\u5408\u8A08 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u9805\u76EE, ", select, _jsx(Text, __assign({ type: "right" }, { children: "/\u30DA\u30FC\u30B8" }), void 0)] }, void 0));
    },
    pageStatsStatic: function (_a) {
        var total = _a.total, pageSize = _a.pageSize, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["\u5408\u8A08 ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " \u9805\u76EE,", _jsx(Text, __assign({ type: "middle" }, { children: pageSize }), void 0), " /\u30DA\u30FC\u30B8"] }, void 0));
    },
    selectWidth: 100,
    items: '',
};
export var Pop = __assign({}, common);
export var PreviewImage = {
    alt: '画像のダウンロードに失敗しました',
    prev: '前',
    next: '次',
    rotate: '回転',
};
export var RangePicker = {
    7: '7日間',
    30: '30日間',
};
export var Select = {
    input: '選択',
    empty: '見つかりません',
    tagSeparator: ', ',
    create: '+作成: ',
};
export var Sweetalert = __assign(__assign({}, common), { title: 'アラート' });
export var Switch = {
    checked: 'オン',
    unchecked: 'オフ',
};
export var Grid = __assign(__assign({}, common), { emptyLabel: 'データがありません' });
export var Cascader = __assign(__assign({}, common), { title: 'タイトル', placeholder: '選択', searchPlaceholder: '選択/検索', searchEmpty: '見つかりません', empty: '見つかりません', loading: 'ローディング…' });
var QUARTER_NAMES = ['1期', '2期', '3期', '4期'];
export var TimePicker = function () {
    setLocale(jaJP);
    return __assign(__assign({}, common), { time: '時間を選択', date: '日付を選択', week: '週を選択', month: '月を選択', quarter: '期を選択', year: '年を選択', range: '範囲を選択', timeErrorPop: '選択された時間が無効です', dateErrorPop: '選択された日付が無効です', start: '開始日', end: '終了日', startTime: '開始時間', endTime: '終了時間', to: '〜', current: {
            time: '現在',
            date: '今日',
            week: '今週',
            month: '今月',
            year: '今年',
        }, panel: {
            hour: '',
            minute: '',
            second: '',
            year: '',
            hourSelect: '時間を選択',
            minuteSelect: '分を選択',
            secondSelect: '秒を選択',
            titleFormat: 'MMMM YYYY',
            quarterNames: QUARTER_NAMES,
            yearQuarterName: function (_a) {
                var year = _a.year, quarter = _a.quarter;
                var val = QUARTER_NAMES[quarter];
                return year + "/" + val;
            },
            dayNames: ['日', '月', '火', '水', '木', '金', '土'],
            monthNames: [
                '1月',
                '2月',
                '3月',
                '4月',
                '5月',
                '6月',
                '7月',
                '8月',
                '9月',
                '10月',
                '11月',
                '12月',
            ],
        } });
};
export var Upload = __assign(__assign({}, common), { delete: '削除', retry: '再度試す', failed: '失敗', limit: 'ファイル数の上限に達しました', add: 'ファイル追加', uploading: 'アップロード中' });
export var Mention = {
    noContent: '該当ありません。SPACEキーで終了',
};
export var Transfer = {
    placeholder: '',
    item: '項目',
    items: '項目',
    emptyLabel: '',
};
export var Form = {
    required: '必須',
};
export var NumberInput = {
    min: '最小値は以下にすることはできません',
    max: '最大値はこれより大きくすることはできません',
};
